import{Q as i,br as m,c as n,am as r,Z as l,B as u,S as c,a4 as h}from"./index-Bduq4vJM.js";import{I as f}from"./ItemsListing-Be0Rl7jr.js";import"./MediaItemThumb-CN4TRL8T.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-B-hzVPBy.js";import"./Button-DDaesvMx.js";import"./VBtn-DWiYTBpb.js";import"./VCheckbox-BiGeI08h.js";import"./VCheckboxBtn-DLibXb0-.js";import"./PanelviewItemCompact-C9loINH4.js";import"./VSpacer-BnmXZ56R.js";/* empty css              */import"./Container-Ps6BlEWu.js";import"./VContainer-BVUS8uFb.js";import"./Toolbar-MtNZFNYL.js";import"./VToolbar-CG7bivmQ.js";import"./VTextField-lpT7m_Xn.js";import"./VInfiniteScroll-Ar7Xm9mt.js";import"./layout-B2wBEHPQ.js";import"./VRow-Cj9YdJtG.js";import"./VVirtualScroll-VdTkqEkN.js";import"./VAlert-BjDi0iTj.js";const F=i({__name:"BrowseView",props:{path:{}},setup(a){const t=a,{t:e}=m(),s=n(()=>!t.path||t.path=="root"?e("browse"):r("bp6")?e("browse")+" | "+t.path:r("bp3")?t.path:e("browse")),p=async function(o){return await h.browse(t.path)};return(o,w)=>(c(),l("section",null,[u(f,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"show-select-button":!!(o.path&&o.path!="root"),"load-items":p,"sort-keys":["original","name","name_desc"],title:s.value,path:o.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["show-select-button","title","path"])]))}});export{F as default};
