import{Q as c,o as k,R as s,S as t,ag as R,a0 as n,am as b,bp as y,U as o,au as V,Z as p,as as C,B as d,a9 as w,aa as $,W as B,ab as u,bo as _,an as h,G as A,$ as I,ao as M,bq as T,a5 as m}from"./index-Bduq4vJM.js";import{P as N}from"./PanelviewItemCompact-C9loINH4.js";import{V as W}from"./VToolbar-CG7bivmQ.js";import{a as g}from"./VBtn-DWiYTBpb.js";import{V as z}from"./VAlert-BjDi0iTj.js";import{_ as E}from"./_plugin-vue_export-helper-DlAUqK2U.js";const P=c({__name:"Carousel",setup(v){return k(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(r,l)=>{const e=R("swiper");return t(),s(e,{"slides-per-view":n(y)(r.$vuetify.display.width)+.5,"space-between":24,"free-mode":!0,navigation:!n(b)({breakpoint:"mobile"}),mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:o(()=>[V(r.$slots,"default")]),_:3},8,["slides-per-view","navigation"])}}}),S={class:"mr-3"},D={key:0},L=c({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean}},emits:["update:settings"],setup(v,{emit:r}){const l=r;return(e,a)=>{const f=R("swiper-slide");return t(),p("div",{class:C(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[d(W,{class:"header",color:"transparent"},{prepend:o(()=>[d(h,{icon:e.widgetRow.icon},null,8,["icon"])]),title:o(()=>[B("span",S,u(e.widgetRow.title),1),e.widgetRow.subtitle&&n(b)("bp6")?(t(),s(_,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):w("",!0)]),append:o(()=>[e.editMode&&e.widgetRow.settings?(t(),p("div",D,[e.widgetRow.settings.position!==0?(t(),s(g,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:a[0]||(a[0]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):w("",!0),d(g,{icon:"mdi-chevron-down",onClick:a[1]||(a[1]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),d(g,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:a[2]||(a[2]=i=>l("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),s($,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):w("",!0)]),_:1}),e.widgetRow.items.length>0?(t(),s(P,{key:0},{default:o(()=>[(t(!0),p(A,null,I(e.widgetRow.items,i=>(t(),s(f,{key:i.uri},{default:o(()=>[d(N,{item:i,"permanent-overlay":![n(m).ALBUM,n(m).TRACK,n(m).RADIO].includes(i.media_type),"is-available":n(T)(i),disabled:e.editMode},null,8,["item","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),s(z,{key:1},{default:o(()=>[M(u(e.$t("no_content")),1)]),_:1}))],2)}}}),Q=E(L,[["__scopeId","data-v-d3794258"]]);export{Q as W};
